

rvexp <- function (n=1, rate=1) {
  rvvapply(rexp, n.=n, rate=rate)
}


